# Flask-CKEditor

CKEditor integration for Flask, including image upload, code syntax highlighting and more.

## Links

* [Documentation](https://flask-ckeditor.readthedocs.io/en/latest/)
* [PyPI](https://pypi.org/project/Flask-CKEditor/)
* [Examples](https://github.com/greyli/flask-ckeditor/tree/master/examples)

## License

This project is licensed under the MIT License (see the `LICENSE` file for details).
